@@ -3,7 +3,8 @@ PREFIX_PX_COOKIE_V3 = '_px3'
 PREFIX_PX_TOKEN_V1 = '1'
 PREFIX_PX_TOKEN_V3 = '3'
 PREFIX_PX_DATA_ENRICHMENT = '_pxde'
-PREFIX_PXVID = '_pxvid'
+PREFIX_PXVID = 'pxvid'
+PREFIX_PXHD = '_pxhd'
 MOBILE_SDK_HEADER = "x-px-authorization"
 MOBILE_SDK_ORIGINAL_HEADER = "x-px-original-token"
 MOBILE_SDK_CONNECTION_ERROR_CODE = '2'
@@ -29,7 +30,7 @@ ENFORCER_TRUE_IP_HEADER = 'x-px-enforcer-true-ip'
 EMPTY_GIF_B64 = 'R0lGODlhAQABAPAAAAAAAAAAACH5BAEAAAAALAAAAAABAAEAAAICRAEAOw=='
 COLLECTOR_HOST = 'collector.perimeterx.net'
 FIRST_PARTY_FORWARDED_FOR = 'X-FORWARDED-FOR'
-MODULE_VERSION = 'Python WSGI Module v2.3.1'
+MODULE_VERSION = 'Python WSGI Module{} v3.0.2'
 API_RISK = '/api/v3/risk'
 PAGE_REQUESTED_ACTIVITY = 'page_requested'
 BLOCK_ACTIVITY = 'block'
