@@ -29,7 +29,8 @@ def verify(ctx, config):
             return False
 
         px_cookie_builder = PxCookie(config)
-        px_cookie = px_cookie_builder.build_px_cookie(px_cookies=ctx.px_cookies,
+
+        cookie_version, px_cookie = px_cookie_builder.build_px_cookie(px_cookies=ctx.px_cookies,
                                                       user_agent=ctx.user_agent)
         # Mobile SDK traffic
         if px_cookie and ctx.is_mobile:
@@ -46,7 +47,7 @@ def verify(ctx, config):
         if not px_cookie.deserialize():
             cookie = px_cookie._hmac + ":" + px_cookie._raw_cookie
             logger.error('Cookie decryption failed, value: {}'.format(cookie))
-            ctx.px_orig_cookie = cookie
+            ctx.px_cookie_raw = cookie_version + "=" + cookie
             ctx.s2s_call_reason = 'cookie_decryption_failed'
             return False
 
@@ -54,7 +55,7 @@ def verify(ctx, config):
         ctx.uuid = px_cookie.get_uuid()
         if px_cookie.get_vid():
             ctx.vid = px_cookie.get_vid()
-            ctx.vid_source = 'risk_cookie'
+            ctx.enforcer_vid_source = 'risk_cookie'
         ctx.decoded_cookie = px_cookie.decoded_cookie
         ctx.cookie_hmac = px_cookie.get_hmac()
         ctx.block_action = px_cookie.get_action()
@@ -86,6 +87,6 @@ def verify(ctx, config):
     except Exception, err:
         traceback.print_exc()
         logger.debug('Unexpected exception while evaluating Risk cookie. Error: {}'.format(err))
-        ctx.px_orig_cookie = px_cookie._raw_cookie
+        ctx.px_cookie_raw = px_cookie._raw_cookie
         ctx.s2s_call_reason = 'cookie_decryption_failed'
         return False
