@@ -1,9 +1,15 @@
 import time
 
 import requests
+import os
 
+#pylint: disable=import-error
+if os.environ.get('SERVER_SOFTWARE','').startswith('Google'):
+    import requests_toolbelt.adapters.appengine
+    requests_toolbelt.adapters.appengine.monkeypatch()
+#pylint: enable=import-error
 
-def send(full_url, body, headers, config, method):
+def send(full_url, body, headers, config, method, raise_error = False):
     """
     Returns the appropriate response parameters according to blocking parameters
     :param string full_url:
@@ -29,5 +35,6 @@ def send(full_url, body, headers, config, method):
         logger.debug('PerimeterX server call took {} ms'.format(request_time * 1000))
         return response
     except requests.exceptions.RequestException as err:
-        logger.debug('Received RequestException. Error: {}'.format(err))
-        raise err
+        logger.debug('PerimeterX Received Request Exception. Error: {}'.format(err))
+        if raise_error:
+            raise err
